==> invoice-client-4.1.5-20200228.110036-65-sources.jar: com/xforceplus/seller/invoice/client/model/pdf/AutoPdfControlInfo.java <==
package com.xforceplus.seller.invoice.client.model.pdf;

import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.swagger.annotations.ApiModelProperty;
import javax.validation.Valid;

public class AutoPdfControlInfo {
    @JsonProperty("templateVersion")
    private String templateVersion = null;
    @JsonProperty("productOil")
    private String productOil = null;

    public AutoPdfControlInfo(String templateVersion, String productOil) {
        this.templateVersion = templateVersion;
        this.productOil = productOil;
    }

    public AutoPdfControlInfo() {
    }

    @JsonIgnore
    public AutoPdfControlInfo templateVersion(String templateVersion) {
        this.templateVersion = templateVersion;
        return this;
    }

    @ApiModelProperty("版式文件版本 (0-使用5行模版, 1-使用8行模版，无值等同0)(仅服务器开电票使用)")
    public String getTemplateVersion() {
        return this.templateVersion;
    }

    public void setTemplateVersion(String templateVersion) {
        this.templateVersion = templateVersion;
    }

    @JsonIgnore
    public AutoPdfControlInfo productOil(String productOil) {
        this.productOil = productOil;
        return this;
    }

    @Valid
    @ApiModelProperty("成品油标识")
    public String getProductOil() {
        return this.productOil;
    }

    public void setProductOil(String productOil) {
        this.productOil = productOil;
    }

    private String toIndentedString(Object o) {
        return o == null ? "null" : o.toString().replace("\n", "\n    ");
    }

}

==> invoice-client-4.2.1-20250102.034116-2-sources.jar: com/xforceplus/seller/invoice/client/model/pdf/AutoPdfControlInfo.java <==
package com.xforceplus.seller.invoice.client.model.pdf;

import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.swagger.annotations.ApiModelProperty;
import javax.validation.Valid;

public class AutoPdfControlInfo {
    @JsonProperty("templateVersion")
    private String templateVersion = null;
    @JsonProperty("productOil")
    private String productOil = null;
    @JsonProperty("InvalidFlag")
    private boolean invalidFlag = false;

    public AutoPdfControlInfo(String templateVersion, String productOil, boolean invalidFlag) {
        this.templateVersion = templateVersion;
        this.productOil = productOil;
        this.invalidFlag = invalidFlag;
    }

    public AutoPdfControlInfo() {
    }

    @JsonIgnore
    public AutoPdfControlInfo templateVersion(String templateVersion) {
        this.templateVersion = templateVersion;
        return this;
    }

    @ApiModelProperty("版式文件版本 (0-使用5行模版, 1-使用8行模版，无值等同0)(仅服务器开电票使用)")
    public String getTemplateVersion() {
        return this.templateVersion;
    }

    public void setTemplateVersion(String templateVersion) {
        this.templateVersion = templateVersion;
    }

    @JsonIgnore
    public AutoPdfControlInfo productOil(String productOil) {
        this.productOil = productOil;
        return this;
    }

    @Valid
    @ApiModelProperty("成品油标识")
    public String getProductOil() {
        return this.productOil;
    }

    public void setProductOil(String productOil) {
        this.productOil = productOil;
    }

    private String toIndentedString(Object o) {
        return o == null ? "null" : o.toString().replace("\n", "\n    ");
    }


    @JsonIgnore
    public AutoPdfControlInfo invalidFlag(boolean invalidFlag) {
        this.invalidFlag = invalidFlag;
        return this;
    }

    @ApiModelProperty("发票状态字样标识")
    public boolean getInvalidFlag() {
        return this.invalidFlag;
    }

    public void setInvalidFlag(boolean invalidFlag) {
        this.invalidFlag = invalidFlag;
    }


}
